import { eventWithTime, listenerHandler } from '@highlight-run/rrweb/dist/types';
import { Sdk } from './graph/generated/operations';
import { ConsoleMessage, ErrorMessage, NetworkResourceContent } from '../../frontend/src/util/shared-types';
export declare const HighlightWarning: (context: string, msg: any) => void;
declare class Logger {
    debug: boolean | undefined;
    constructor(debug?: boolean);
    log(...data: any[]): void;
}
export declare type DebugOptions = {
    clientInteractions?: boolean;
    domRecording?: boolean;
};
export declare type HighlightClassOptions = {
    organizationID: number | string;
    debug?: boolean | DebugOptions;
    backendUrl?: string;
    disableNetworkRecording?: boolean;
    disableConsoleRecording?: boolean;
    enableSegmentIntegration?: boolean;
    enableStrictPrivacy?: boolean;
    firstloadVersion: string;
};
/**
 * Subset of HighlightClassOptions that is stored with the session. These fields are stored for debugging purposes.
 */
declare type HighlightClassOptionsInternal = Omit<HighlightClassOptions, 'firstloadVersion'>;
declare type PropertyType = {
    type?: 'track' | 'session';
    source?: Source;
};
declare type Source = 'segment' | undefined;
declare type SessionData = {
    sessionID: number;
    sessionStartTime?: number;
    userIdentifier?: string;
    userObject?: Object;
};
export declare class Highlight {
    organizationID: string;
    graphqlSDK: Sdk;
    events: eventWithTime[];
    errors: ErrorMessage[];
    messages: ConsoleMessage[];
    networkContents: NetworkResourceContent[];
    sessionData: SessionData;
    ready: boolean;
    logger: Logger;
    disableNetworkRecording: boolean | undefined;
    disableConsoleRecording: boolean | undefined;
    enableSegmentIntegration: boolean | undefined;
    enableStrictPrivacy: boolean;
    debugOptions: DebugOptions;
    stopRecording: listenerHandler[];
    firstloadVersion: string;
    _optionsInternal: HighlightClassOptionsInternal;
    constructor(options: HighlightClassOptions);
    identify(user_identifier: string, user_object?: {}, source?: Source): Promise<void>;
    pushCustomError(message: string): Promise<void>;
    addProperties(properties_obj?: {}, typeArg?: PropertyType): Promise<void>;
    initialize(organization_id?: number | string): Promise<void>;
    _save(): Promise<void>;
}
declare global {
    interface Console {
        defaultLog: any;
        defaultError: any;
        defaultWarn: any;
        defaultDebug: any;
    }
}
export {};
